==> mediawiki-1.21.1.tar.gz: mediawiki-1.21.1/languages/messages/MessagesNiu.php <==
<?php
/** Niuean (ko e vagahau Niuē)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author Rotemliss
 * @author Sioneholof
 */

$messages = array(
# Dates
'sunday' => 'Aho Tapu',
'monday' => 'Aho Gofua',
'tuesday' => 'Aho Ua',
'wednesday' => 'Aho Lotu',
'thursday' => 'Aho Tuloto',
'friday' => 'Aho Falaile',
'saturday' => 'Aho Faiumu',
'january' => 'Ianuali',
'february' => 'Fepuali',
'march' => 'Masi',
'april' => 'Apelila',
'may_long' => 'Me',
'june' => 'Iuni',
'july' => 'Iulai',
'august' => 'Aokuso',
'september' => 'Sepetema',
'october' => 'Oketopa',
'november' => 'Novema',
'december' => 'Tesemo',
'january-gen' => 'Ianuali',
'february-gen' => 'Fepuali',
'march-gen' => 'Masi',
'april-gen' => 'Apelila',
'may-gen' => 'Me',
'june-gen' => 'Iuni',
'july-gen' => 'Iulai',
'august-gen' => 'Aokuso',
'september-gen' => 'Sepetema',
'october-gen' => 'Oketopa',
'november-gen' => 'Novema',
'december-gen' => 'Tesemo',
'may' => 'Me',

'article' => 'Tohi Tala',
'cancel' => 'Tiaki',
'mytalk' => 'Haaku tutala',
'navigation' => 'Navikati',

# Cologne Blue skin
'qbedit' => 'Fakahakohako',
'qbspecialpages' => 'Tau Lau Mahuiga',

'help' => 'Lagomatai',
'search' => 'Kumi',
'searchbutton' => 'Kumi',
'go' => 'Fano',
'searcharticle' => 'Fano',
'history_short' => 'Liu onoono atu ki tua',
'printableversion' => 'Mitaki lolomi',
'permalink' => 'Matutakiaga mautumau',
'edit' => 'Fakahakohako',
'delete' => 'Tamate',
'protect' => 'Puipui',
'talkpagelinktext' => 'Tutala',
'talk' => 'Fakatutala',
'toolbox' => 'Puha Mena Gahua',
'otherlanguages' => 'Ke he falu vagahau',
'jumptonavigation' => 'navikati',
'jumptosearch' => 'kumi',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite' => 'Hagaao ke he {{SITENAME}}',
'aboutpage' => 'Project: Hagaao',
'currentevents' => 'Tau Fakaholoaga Mogonei',
'edithelp' => 'Lagomatai ke he Fakahakohako',
'helppage' => 'Help: Ke lata mo e tau mena i loto',
'mainpage' => 'Matapatu Lau',
'mainpage-description' => 'Matapatu Lau',
'portal' => 'Maaga ke Matutaki',
'portal-url' => 'Project:Ko e lau auloa ma maaga',
'privacy' => 'Ko e puipuiaga ke he tau talahauaga mo e talahauaga fakatagata',

'youhavenewmessages' => 'Fai $1 ($2).',
'newmessageslink' => 'tau tohi foou',
'youhavenewmessagesmulti' => 'Fai tohi foou a koe he $1',
'editsection' => 'fakahakohako',
'editold' => 'fakahakohako',
'editsectionhint' => 'Hiki e vala e: $1',
'red-link-title' => '$1 (nakai fai lau pihia i i loto e)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Lau',
'nstab-user' => 'Lau he tagata',

# General errors
'viewsource' => 'Kitekite ke mouaga',

# Login and logout pages
'yourname' => 'Matahigoa he tagata:',
'yourpassword' => 'Kupu fufu:',
'yourpasswordagain' => 'Liu lolomi e kupu fufu:',
'remembermypassword' => 'Manatu e haaku loko ini (for a maximum of $1 {{PLURAL:$1|day|days}})',
'login' => 'Hu ki loto',
'nav-login-createaccount' => 'Hu ki loto / talaga e poko',
'userlogin' => 'Hu ki loto / talaga e poko',
'logout' => 'Hu mai ki tua',
'userlogout' => 'Hu mai ki tua',
'notloggedin' => 'Ai la hu ki loto',
'createaccount' => 'Talaga e poko',
'gotaccountlink' => 'Hu ki loto',

# Special:PasswordReset
'passwordreset-username' => 'Matahigoa he tagata',

# Edit pages
'summary' => 'Fakakatoakatoa:',
'minoredit' => 'Ko e fakahakohako fakatote',
'watchthis' => 'Onoono e lau e',
'savearticle' => 'Taofi e lau',
'showpreview' => 'Fakakite e foliga',
'showdiff' => 'Fakakite e tau hikihiki',
'loginreqlink' => 'hu ki loto',

# History pages
'currentrev' => 'Kitekiteaga mogonei',
'currentrevisionlink' => 'Kitekiteaga mogonei',

# Diffs
'editundo' => 'Liuaki',

# Preferences page
'mypreferences' => 'Haaku a tau manako',
'prefsnologin' => 'Ai la hu ki loto',
'prefs-rc' => 'Hikihikiaga mogoia',
'searchresultshead' => 'Kumi',
'youremail' => 'Meli hila:',
'username' => 'Matahigoa he tagata:',
'email' => 'Meli hila',

# Recent changes
'recentchanges' => 'Hikihikiaga mogoia',
'hist' => 'Liu onoono atu ki tua',

# Recent changes linked
'recentchangeslinked' => 'Falu hikihiki',
'recentchangeslinked-feed' => 'Falu hikihiki',
'recentchangeslinked-toolbox' => 'Falu hikihiki',

# Upload
'upload' => 'Fakafano e faila',
'uploadbtn' => 'Fakafano e faila',
'uploadnologin' => 'Ai la hu ki loto',
'filedesc' => 'Fakakatoakatoa',
'fileuploadsummary' => 'Fakakatoakatoa:',
'watchthisupload' => 'Onoono e lau e',

# File description page
'filehist-deleteone' => 'tamate',

# File deletion
'filedelete-submit' => 'Tamate',

# Random page
'randompage' => 'Lau fifili',

'brokenredirects-edit' => 'fakahakohako',
'brokenredirects-delete' => 'tamate',

# Miscellaneous special pages
'newpages-username' => 'Matahigoa he tagata:',
'move' => 'Une',
'movethispage' => 'Une e lau e',

# Book sources
'booksources-go' => 'Fano',

# Special:LinkSearch
'linksearch-ok' => 'Kumi',

# Watchlist
'watchlist' => 'Ko e haaku lau kitekite',
'mywatchlist' => 'Ko e haaku lau kitekite',
'watchnologin' => 'Ai la hu ki loto',
'watch' => 'Kitekite',
'watchthispage' => 'Onoono e lau e',

# Delete
'delete-legend' => 'Tamate',

# Protect
'prot_1movedto2' => '[[$1]] kua une ke he [[$2]]',

# Restrictions (nouns)
'restriction-edit' => 'Fakahakohako',
'restriction-move' => 'Une',

# Undelete
'undelete-search-submit' => 'Kumi',

# Contributions
'contributions' => 'Tau lagomatai tagata',
'mycontris' => 'Haaku a tau lagomatai',

'sp-contributions-submit' => 'Kumi',

# What links here
'whatlinkshere' => 'Ko e tau matutakiaga he mena e',

# Block/unblock
'ipbreason' => 'Kakano:',
'ipblocklist-submit' => 'Kumi',

# Move page
'movenologin' => 'Ai la hu ki loto',
'move-watch' => 'Onoono e lau e',
'movedto' => 'kua une ke he',
'movereason' => 'Kakano:',

# Namespace 8 related
'allmessages' => 'Tau fakailoaga',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Haaku a tau manako',
'tooltip-pt-login' => 'Kua lata ia koe ke loko ini, kae pule ni e a koe, ai pehe ko e masi a koe ke loko ini',
'tooltip-pt-logout' => 'Hu mai ki tua',
'tooltip-ca-talk' => 'Tutala ke he tau matapatu lau',
'tooltip-ca-edit' => 'Maeke ia koe ke hiki, uta kehe mo e lalafi atu falu mena ke he lau nei.  Fakamolemole ti fakaaoga e PREVIEW patani to taofi mau.',
'tooltip-search' => 'Kumi {{SITENAME}}',
'tooltip-search-fulltext' => 'Kumi ke he tau lau oti e kupu e',
'tooltip-p-logo' => 'Matapatu Lau',
'tooltip-n-mainpage-description' => 'Fano ke he matapatu lau',
'tooltip-n-portal' => 'Hagao ke he gahua lahi, ko e heigoa kua lata a koe ke taute, mo e moua mai i fe e tau mena',
'tooltip-n-currentevents' => 'Kumi e tau vala tala kehekehe hagao ke he tau mena tutupu',
'tooltip-n-recentchanges' => 'Hae e tau hikihiki foou he wiki',
'tooltip-n-randompage' => 'Tuku mai noa ni e ha lau',
'tooltip-n-help' => 'Ko e matakavi ke kumi ki ai',
'tooltip-t-whatlinkshere' => 'Ko e tau lau wiki oti ne fai matutaki mai ke he lau e',
'tooltip-t-upload' => 'Fakahu ki loto e tau faila',
'tooltip-t-specialpages' => 'Ko e tau lau oti kua kehekehe',

# Special:NewFiles
'ilsubmit' => 'Kumi',

# Bad image list
'bad_image_list' => 'Ko e tau mena ni ne fakakite mai ka onoono ki ai (ko e tau laini ne kamata aki e *).
Ko e liniki fakamua he laini ko e liniki ke he faila kelea.
Ko e tau liniki foki i lalo he laini taha ko e tau laini fifili pauaki, i.e. ko e tau lau ne fai faila i loto he laini ia.',

# Multipage image navigation
'imgmultigo' => 'Fano!',

# Table pager
'table_pager_limit_submit' => 'Fano',

# Special:Version
'version-specialpages' => 'Tau Lau Mahuiga',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Kumi',

# Special:SpecialPages
'specialpages' => 'Tau Lau Mahuiga',

);

==> mediawiki-1.22.4.tar.gz: mediawiki-1.22.4/languages/messages/MessagesNiu.php <==
<?php
/** Niuean (ko e vagahau Niuē)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77
 * @author Rotemliss
 * @author Sioneholof
 */

$messages = array(
# Dates
'sunday' => 'Aho Tapu',
'monday' => 'Aho Gofua',
'tuesday' => 'Aho Ua',
'wednesday' => 'Aho Lotu',
'thursday' => 'Aho Tuloto',
'friday' => 'Aho Falaile',
'saturday' => 'Aho Faiumu',
'january' => 'Ianuali',
'february' => 'Fepuali',
'march' => 'Masi',
'april' => 'Apelila',
'may_long' => 'Me',
'june' => 'Iuni',
'july' => 'Iulai',
'august' => 'Aokuso',
'september' => 'Sepetema',
'october' => 'Oketopa',
'november' => 'Novema',
'december' => 'Tesemo',
'january-gen' => 'Ianuali',
'february-gen' => 'Fepuali',
'march-gen' => 'Masi',
'april-gen' => 'Apelila',
'may-gen' => 'Me',
'june-gen' => 'Iuni',
'july-gen' => 'Iulai',
'august-gen' => 'Aokuso',
'september-gen' => 'Sepetema',
'october-gen' => 'Oketopa',
'november-gen' => 'Novema',
'december-gen' => 'Tesemo',
'may' => 'Me',

'article' => 'Tohi Tala',
'cancel' => 'Tiaki',
'mytalk' => 'Haaku tutala',
'navigation' => 'Navikati',

# Cologne Blue skin
'qbedit' => 'Fakahakohako',
'qbspecialpages' => 'Tau Lau Mahuiga',

'help' => 'Lagomatai',
'search' => 'Kumi',
'searchbutton' => 'Kumi',
'go' => 'Fano',
'searcharticle' => 'Fano',
'history_short' => 'Liu onoono atu ki tua',
'printableversion' => 'Mitaki lolomi',
'permalink' => 'Matutakiaga mautumau',
'edit' => 'Fakahakohako',
'delete' => 'Tamate',
'protect' => 'Puipui',
'talkpagelinktext' => 'Tutala',
'talk' => 'Fakatutala',
'toolbox' => 'Puha Mena Gahua',
'otherlanguages' => 'Ke he falu vagahau',
'jumptonavigation' => 'navikati',
'jumptosearch' => 'kumi',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite' => 'Hagaao ke he {{SITENAME}}',
'aboutpage' => 'Project: Hagaao',
'currentevents' => 'Tau Fakaholoaga Mogonei',
'edithelp' => 'Lagomatai ke he Fakahakohako',
'helppage' => 'Help: Ke lata mo e tau mena i loto',
'mainpage' => 'Matapatu Lau',
'mainpage-description' => 'Matapatu Lau',
'portal' => 'Maaga ke Matutaki',
'portal-url' => 'Project:Ko e lau auloa ma maaga',
'privacy' => 'Ko e puipuiaga ke he tau talahauaga mo e talahauaga fakatagata',

'youhavenewmessages' => 'Fai $1 ($2).',
'newmessageslink' => 'tau tohi foou',
'youhavenewmessagesmulti' => 'Fai tohi foou a koe he $1',
'editsection' => 'fakahakohako',
'editold' => 'fakahakohako',
'editsectionhint' => 'Hiki e vala e: $1',
'red-link-title' => '$1 (nakai fai lau pihia i i loto e)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Lau',
'nstab-user' => 'Lau he tagata',

# General errors
'viewsource' => 'Kitekite ke mouaga',

# Login and logout pages
'welcomecreation' => '== Fakalofa atu, kua fiafia ke hu mai $1 ==
Kua talaga e haau a poko.
Ua nimo ke hiki e haau tau [[Special:Preferences|manako {{SITENAME}}]].',
'yourname' => 'Matahigoa he tagata:',
'yourpassword' => 'Kupu fufu:',
'yourpasswordagain' => 'Liu lolomi e kupu fufu:',
'remembermypassword' => 'Manatu e haaku loko ini (for a maximum of $1 {{PLURAL:$1|day|days}})',
'login' => 'Hu ki loto',
'nav-login-createaccount' => 'Hu ki loto / talaga e poko',
'userlogin' => 'Hu ki loto / talaga e poko',
'logout' => 'Hu mai ki tua',
'userlogout' => 'Hu mai ki tua',
'notloggedin' => 'Ai la hu ki loto',
'createaccount' => 'Talaga e poko',
'gotaccountlink' => 'Hu ki loto',

# Special:PasswordReset
'passwordreset-username' => 'Matahigoa he tagata',

# Edit pages
'summary' => 'Fakakatoakatoa:',
'minoredit' => 'Ko e fakahakohako fakatote',
'watchthis' => 'Onoono e lau e',
'savearticle' => 'Taofi e lau',
'showpreview' => 'Fakakite e foliga',
'showdiff' => 'Fakakite e tau hikihiki',
'loginreqlink' => 'hu ki loto',

# History pages
'currentrev' => 'Kitekiteaga mogonei',
'currentrevisionlink' => 'Kitekiteaga mogonei',

# Diffs
'editundo' => 'Liuaki',

# Preferences page
'mypreferences' => 'Haaku a tau manako',
'prefsnologin' => 'Ai la hu ki loto',
'prefs-rc' => 'Hikihikiaga mogoia',
'searchresultshead' => 'Kumi',
'youremail' => 'Meli hila:',
'username' => 'Matahigoa he tagata:',
'email' => 'Meli hila',

# Recent changes
'recentchanges' => 'Hikihikiaga mogoia',
'hist' => 'Liu onoono atu ki tua',

# Recent changes linked
'recentchangeslinked' => 'Falu hikihiki',
'recentchangeslinked-feed' => 'Falu hikihiki',
'recentchangeslinked-toolbox' => 'Falu hikihiki',

# Upload
'upload' => 'Fakafano e faila',
'uploadbtn' => 'Fakafano e faila',
'uploadnologin' => 'Ai la hu ki loto',
'filedesc' => 'Fakakatoakatoa',
'fileuploadsummary' => 'Fakakatoakatoa:',
'watchthisupload' => 'Onoono e lau e',

# File description page
'filehist-deleteone' => 'tamate',

# File deletion
'filedelete-submit' => 'Tamate',

# Random page
'randompage' => 'Lau fifili',

'brokenredirects-edit' => 'fakahakohako',
'brokenredirects-delete' => 'tamate',

# Miscellaneous special pages
'newpages-username' => 'Matahigoa he tagata:',
'move' => 'Une',
'movethispage' => 'Une e lau e',

# Book sources
'booksources-go' => 'Fano',

# Special:LinkSearch
'linksearch-ok' => 'Kumi',

# Watchlist
'watchlist' => 'Ko e haaku lau kitekite',
'mywatchlist' => 'Ko e haaku lau kitekite',
'watchnologin' => 'Ai la hu ki loto',
'watch' => 'Kitekite',
'watchthispage' => 'Onoono e lau e',

# Delete
'delete-legend' => 'Tamate',

# Protect
'prot_1movedto2' => '[[$1]] kua une ke he [[$2]]',

# Restrictions (nouns)
'restriction-edit' => 'Fakahakohako',
'restriction-move' => 'Une',

# Undelete
'undelete-search-submit' => 'Kumi',

# Contributions
'contributions' => 'Tau lagomatai tagata',
'mycontris' => 'Haaku a tau lagomatai',

'sp-contributions-submit' => 'Kumi',

# What links here
'whatlinkshere' => 'Ko e tau matutakiaga he mena e',

# Block/unblock
'ipbreason' => 'Kakano:',
'ipblocklist-submit' => 'Kumi',

# Move page
'movenologin' => 'Ai la hu ki loto',
'move-watch' => 'Onoono e lau e',
'movedto' => 'kua une ke he',
'movereason' => 'Kakano:',

# Namespace 8 related
'allmessages' => 'Tau fakailoaga',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Haaku a tau manako',
'tooltip-pt-login' => 'Kua lata ia koe ke loko ini, kae pule ni e a koe, ai pehe ko e masi a koe ke loko ini',
'tooltip-pt-logout' => 'Hu mai ki tua',
'tooltip-ca-talk' => 'Tutala ke he tau matapatu lau',
'tooltip-ca-edit' => 'Maeke ia koe ke hiki, uta kehe mo e lalafi atu falu mena ke he lau nei.  Fakamolemole ti fakaaoga e PREVIEW patani to taofi mau.',
'tooltip-search' => 'Kumi {{SITENAME}}',
'tooltip-search-fulltext' => 'Kumi ke he tau lau oti e kupu e',
'tooltip-p-logo' => 'Matapatu Lau',
'tooltip-n-mainpage-description' => 'Fano ke he matapatu lau',
'tooltip-n-portal' => 'Hagao ke he gahua lahi, ko e heigoa kua lata a koe ke taute, mo e moua mai i fe e tau mena',
'tooltip-n-currentevents' => 'Kumi e tau vala tala kehekehe hagao ke he tau mena tutupu',
'tooltip-n-recentchanges' => 'Hae e tau hikihiki foou he wiki',
'tooltip-n-randompage' => 'Tuku mai noa ni e ha lau',
'tooltip-n-help' => 'Ko e matakavi ke kumi ki ai',
'tooltip-t-whatlinkshere' => 'Ko e tau lau wiki oti ne fai matutaki mai ke he lau e',
'tooltip-t-upload' => 'Fakahu ki loto e tau faila',
'tooltip-t-specialpages' => 'Ko e tau lau oti kua kehekehe',

# Special:NewFiles
'ilsubmit' => 'Kumi',

# Bad image list
'bad_image_list' => 'Ko e tau mena ni ne fakakite mai ka onoono ki ai (ko e tau laini ne kamata aki e *).
Ko e liniki fakamua he laini ko e liniki ke he faila kelea.
Ko e tau liniki foki i lalo he laini taha ko e tau laini fifili pauaki, i.e. ko e tau lau ne fai faila i loto he laini ia.',

# Multipage image navigation
'imgmultigo' => 'Fano!',

# Table pager
'table_pager_limit_submit' => 'Fano',

# Special:Version
'version-specialpages' => 'Tau Lau Mahuiga',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Kumi',

# Special:SpecialPages
'specialpages' => 'Tau Lau Mahuiga',

);
